@@ -35,6 +35,9 @@ FAILEDOPERATION_AUTHFAILURE = 'FailedOperation.AuthFailure'
 # 请求role信息失败。
 FAILEDOPERATION_CALLROLEFAILED = 'FailedOperation.CallRoleFailed'
 
+# CopyAsyncRun 传参异常。
+FAILEDOPERATION_COPYASYNCRUN = 'FailedOperation.CopyAsyncRun'
+
 # 复制函数失败。
 FAILEDOPERATION_COPYFAILED = 'FailedOperation.CopyFailed'
 
@@ -92,6 +95,9 @@ FAILEDOPERATION_GETALIAS = 'FailedOperation.GetAlias'
 # 获取函数代码地址失败。
 FAILEDOPERATION_GETFUNCTIONADDRESS = 'FailedOperation.GetFunctionAddress'
 
+# InstanceNotFound 实例不存在。
+FAILEDOPERATION_INSTANCENOTFOUND = 'FailedOperation.InstanceNotFound'
+
 # 当前账号或命名空间处于欠费状态，请在可用时重试。
 FAILEDOPERATION_INSUFFICIENTBALANCE = 'FailedOperation.InsufficientBalance'
 
@@ -113,6 +119,12 @@ FAILEDOPERATION_PROVISIONCREATETIMER = 'FailedOperation.ProvisionCreateTimer'
 # 删除定时预置任务失败。
 FAILEDOPERATION_PROVISIONDELETETIMER = 'FailedOperation.ProvisionDeleteTimer'
 
+# 预置超过可用。
+FAILEDOPERATION_PROVISIONEDEXCEEDAVAILABLE = 'FailedOperation.ProvisionedExceedAvailable'
+
+# 预置超限。
+FAILEDOPERATION_PROVISIONEDEXCEEDRESERVED = 'FailedOperation.ProvisionedExceedReserved'
+
 # 当前函数版本已有预置任务处于进行中，请稍后重试。
 FAILEDOPERATION_PROVISIONEDINPROGRESS = 'FailedOperation.ProvisionedInProgress'
 
@@ -125,6 +137,9 @@ FAILEDOPERATION_PUBLISHVERSION = 'FailedOperation.PublishVersion'
 # 角色不存在。
 FAILEDOPERATION_QCSROLENOTFOUND = 'FailedOperation.QcsRoleNotFound'
 
+# ReservedExceedTotal 总保留超限。
+FAILEDOPERATION_RESERVEDEXCEEDTOTAL = 'FailedOperation.ReservedExceedTotal'
+
 # 当前函数已有保留并发设置任务处于进行中，请稍后重试。
 FAILEDOPERATION_RESERVEDINPROGRESS = 'FailedOperation.ReservedInProgress'
 
@@ -185,6 +200,9 @@ INVALIDPARAMETER_PARAMERROR = 'InvalidParameter.ParamError'
 # 请求参数不合法。
 INVALIDPARAMETER_PAYLOAD = 'InvalidParameter.Payload'
 
+# RoleCheck 传参有误。
+INVALIDPARAMETER_ROLECHECK = 'InvalidParameter.RoleCheck'
+
 # RoutingConfig参数传入错误。
 INVALIDPARAMETER_ROUTINGCONFIG = 'InvalidParameter.RoutingConfig'
 
@@ -347,12 +365,18 @@ INVALIDPARAMETERVALUE_GITDIRECTORY = 'InvalidParameterValue.GitDirectory'
 # GitPassword不符合规范。
 INVALIDPARAMETERVALUE_GITPASSWORD = 'InvalidParameterValue.GitPassword'
 
+# GitPasswordSecret 传参有误。
+INVALIDPARAMETERVALUE_GITPASSWORDSECRET = 'InvalidParameterValue.GitPasswordSecret'
+
 # GitUrl不符合规范。
 INVALIDPARAMETERVALUE_GITURL = 'InvalidParameterValue.GitUrl'
 
 # GitUserName不符合规范。
 INVALIDPARAMETERVALUE_GITUSERNAME = 'InvalidParameterValue.GitUserName'
 
+# GitUserNameSecret 传参有误。
+INVALIDPARAMETERVALUE_GITUSERNAMESECRET = 'InvalidParameterValue.GitUserNameSecret'
+
 # Handler传入错误。
 INVALIDPARAMETERVALUE_HANDLER = 'InvalidParameterValue.Handler'
 
@@ -662,6 +686,9 @@ RESOURCENOTFOUND_CDN = 'ResourceNotFound.Cdn'
 # 指定的cfs下未找到您所指定的挂载点。
 RESOURCENOTFOUND_CFSMOUNTINSNOTMATCH = 'ResourceNotFound.CfsMountInsNotMatch'
 
+# CfsProtocolError 参数异常。
+RESOURCENOTFOUND_CFSPROTOCOLERROR = 'ResourceNotFound.CfsProtocolError'
+
 # 检测cfs状态为不可用。
 RESOURCENOTFOUND_CFSSTATUSERROR = 'ResourceNotFound.CfsStatusError'
 
